@@ -36,9 +36,9 @@ class ForkHttp(Fork):
         headers = {}
 
         # Headers
-        if not data["headers"].get("Authorizacion", None) is None:
+        if not data["headers"].get("Authorization", None) is None:
             headers.update({
-                "Authorizacion": data["headers"].get("Authorizacion", None)
+                "Authorization": data["headers"].get("Authorization", None)
             })
 
         # Url base
